@@ -199,8 +199,7 @@ impl Node {
                         let reward_sum = credit_proofs.sum();
                         ops.extend(Self::propagate_credits(credit_proofs)?);
                         // update state
-                        *elder.section_funds.write().await =
-                            SectionFunds::KeepingNodeWallets(reward_wallets.clone());
+                        *section_funds = SectionFunds::KeepingNodeWallets(reward_wallets.clone());
                         let section_key = network_api.section_public_key().await?;
                         info!(
                             "COMPLETED SPLIT. New section: ({}). Total rewards paid: {}.",
@@ -265,7 +264,7 @@ impl Node {
                 let elder = self.role.as_elder_mut()?.clone();
                 let network_api = self.network_api.clone();
                 let handle = tokio::spawn(async move {
-                    elder.section_funds.read().await.remove_node_wallet(name);
+                    elder.section_funds.write().await.remove_node_wallet(name);
                     let our_adults = network_api.our_adults().await;
                     elder
                         .meta_data
@@ -370,7 +369,7 @@ impl Node {
                     Ok(NodeTask::from(vec![
                         elder
                             .transfers
-                            .read()
+                            .write()
                             .await
                             .credit_without_proof(transfer)
                             .await?,
@@ -451,7 +450,7 @@ impl Node {
             NodeDuty::ReadChunk { read, msg_id } => {
                 let adult = self.role.as_adult()?.clone();
                 let handle = tokio::spawn(async move {
-                    let mut ops = vec![adult.chunks.write().await.read(&read, msg_id)];
+                    let mut ops = vec![adult.chunks.read().await.read(&read, msg_id)];
                     ops.extend(adult.chunks.read().await.check_storage().await?);
                     Ok(NodeTask::from(ops))
                 });
@@ -506,7 +505,7 @@ impl Node {
                         .write()
                         .await
                         .increase_full_node_count(node_id)
-                        .await?;
+                        .await;
                     // Accept a new node in place for the full node.
                     Ok(NodeTask::from(vec![NodeDuty::SetNodeJoinsAllowed(true)]))
                 });
@@ -576,6 +575,7 @@ impl Node {
                         vec![
                             elder
                                 .meta_data
+                                // this is a write here as we write the liveness check for each adult
                                 .write()
                                 .await
                                 .read(query, msg_id, client_signed.public_key, origin)
@@ -659,7 +659,7 @@ impl Node {
                     Ok(NodeTask::from(
                         elder
                             .transfers
-                            .read()
+                            .write()
                             .await
                             .process_payment(id, payment, cmd, client_signed, origin)
                             .await?,
